<!-- DOC_TYPE: INDEX -->

# Архитектура

## Runtime Modules

- [Core](./core.md)
- [System](./system.md)
- [Notifications](./notifications.md)
- [Booking](./booking.md)
- [Cabinet](./cabinet.md)
- [Showcase](./showcase.md)

## Примечание

CLI-архитектура переехала в companion package `codex-django-cli`.
Этот репозиторий документирует только runtime package.
